/// 
/// @mainpage	myGenie
/// @details	GUI to set LED PWM
/// @n
/// @n @a	Developed with [embedXcode](http://embedXcode.weebly.com)
///
/// @author	Rei Vilo
/// @author	http://embeddedcomputing.weebly.com
/// @copyright	CC = BY SA NC
/// @date	Dec 17, 2012
/// @version	100
///

// Core library
#include "Arduino.h" // for Arduino 1.0

// Include application, user and local libraries
#include "SoftwareSerial.h"

// Define variables and constants
SoftwareSerial mySerial(2, 3);

#define SCREEN_RESET_PIN  4
#define LED_PIN		 10
#define REPORT_EVENT	 0x07

const uint16_t buttonQuit	= 0x0600; 
const uint16_t sliderValue    	= 0x0500;

uint8_t command = 0;
uint16_t object = 0;
uint16_t value = 0;


boolean readScreen(uint8_t &command0, uint16_t &object0, uint16_t &value0) {
  boolean flag0 = false;
  uint8_t message[6];
  uint8_t checksum = 0x00;
  uint8_t i=0;

  if (mySerial.available()>0) {
    message[i] = mySerial.read();
    command0 = message[0];
    i++;
    checksum = command0;

    if (command0==REPORT_EVENT) {
      if (mySerial.available()>3) {
        message[i] = mySerial.read();
        checksum ^= message[i];
        i++;
        message[i] = mySerial.read();
        checksum ^= message[i];
        i++;
        object0 = message[1] << 8 | message[2];

        message[i] = mySerial.read();
        checksum ^= message[i];
        i++;
        object0 = message[1] << 8 | message[2];
        message[i] = mySerial.read();
        checksum ^= message[i];
        i++;
        value0 = message[3] << 8 | message[4];
      }				
    }
    flag0 = (checksum==mySerial.read());
  }
  return flag0;
}

void setLEDPWM() {
  analogWrite(LED_PIN, (uint8_t)(value & 0xff));
}


// Add setup code
void setup() {
  // Serial port
  mySerial.begin(9600);
  mySerial.flush();

  // Hardware reset of the screen
  pinMode(SCREEN_RESET_PIN, OUTPUT);
  digitalWrite(SCREEN_RESET_PIN, LOW);
  delay(100);
  digitalWrite(SCREEN_RESET_PIN, HIGH);

  // Screen wake-up
  delay(3000); 

  // LED pin
  pinMode(LED_PIN, OUTPUT);
  setLEDPWM();
}

// Add loop code
void loop() {
  if (readScreen(command, object, value)) {
    if (command==0x07) 
      if (object==buttonQuit) {
        value = 0;
        setLEDPWM();
        while(true);
      } 
      else if (object==sliderValue) {
        setLEDPWM();
      }
  }
  delay(100);
}



